@@ -1,6 +1,7 @@
 require 'prometheus/client/registry'
 require 'prometheus/client/mmaped_value'
 require 'logger'
+require 'tmpdir'
 
 module Prometheus
   module Client
@@ -9,10 +10,12 @@ module Prometheus
 
       def initialize
         @value_class = ::Prometheus::Client::MmapedValue
-        @multiprocess_files_dir = ENV['prometheus_multiproc_dir']
         @initial_mmap_file_size = 4 * 1024
         @logger = Logger.new($stdout)
         @pid_provider = Process.method(:pid)
+        @multiprocess_files_dir = ENV.fetch('prometheus_multiproc_dir') do
+          Dir.mktmpdir("prometheus-mmap")
+        end
       end
     end
   end
