@@ -8,6 +8,8 @@ module Prometheus
           if defined?(Oj)
             def load(s)
               Oj.load(s)
+            rescue Oj::ParseError, EncodingError => e
+              raise JSON::ParserError.new(e.message)
             end
           else
             def load(s)
