@@ -37,7 +37,7 @@ module Prometheus
         valid?(labels)
 
         unless @validated.empty? || match?(labels, @validated.first.last)
-          raise InvalidLabelSetError, 'labels must have the same signature'
+          raise InvalidLabelSetError, "labels must have the same signature: (#{label_diff(labels, @validated.first.last)})"
         end
 
         @validated[labels.hash] = labels
@@ -45,6 +45,10 @@ module Prometheus
 
       private
 
+      def label_diff(a, b)
+        "expected keys: #{b.keys.sort}, got: #{a.keys.sort}"
+      end
+
       def match?(a, b)
         a.keys.sort == b.keys.sort
       end
